..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. _overview:

Introduction
------------

.. toctree::
    :maxdepth: 2
    :name: mastertoc

    invenio
    digitalrepositories
    usecases
    history
